@@ -29,28 +29,27 @@ from skimage import exposure
 matplotlib.rcParams['font.size'] = 8
 
 
-def plot_img_and_hist(img, axes, bins=256):
+def plot_img_and_hist(image, axes, bins=256):
     """Plot an image along with its histogram and cumulative histogram.
 
     """
-    img = img_as_float(img)
+    image = img_as_float(image)
     ax_img, ax_hist = axes
     ax_cdf = ax_hist.twinx()
 
     # Display image
-    ax_img.imshow(img, cmap=plt.cm.gray)
+    ax_img.imshow(image, cmap=plt.cm.gray)
     ax_img.set_axis_off()
-    ax_img.set_adjustable('box-forced')
 
     # Display histogram
-    ax_hist.hist(img.ravel(), bins=bins, histtype='step', color='black')
+    ax_hist.hist(image.ravel(), bins=bins, histtype='step', color='black')
     ax_hist.ticklabel_format(axis='y', style='scientific', scilimits=(0, 0))
     ax_hist.set_xlabel('Pixel intensity')
     ax_hist.set_xlim(0, 1)
     ax_hist.set_yticks([])
 
     # Display cumulative distribution
-    img_cdf, bins = exposure.cumulative_distribution(img, bins)
+    img_cdf, bins = exposure.cumulative_distribution(image, bins)
     ax_cdf.plot(bins, img_cdf, 'r')
     ax_cdf.set_yticks([])
 
