@@ -28,11 +28,10 @@ image = color.gray2rgb(grayscale_image)
 red_multiplier = [1, 0, 0]
 yellow_multiplier = [1, 1, 0]
 
-fig, (ax1, ax2) = plt.subplots(ncols=2, figsize=(8, 4), sharex=True, sharey=True)
+fig, (ax1, ax2) = plt.subplots(ncols=2, figsize=(8, 4),
+                               sharex=True, sharey=True)
 ax1.imshow(red_multiplier * image)
 ax2.imshow(yellow_multiplier * image)
-ax1.set_adjustable('box-forced')
-ax2.set_adjustable('box-forced')
 
 ######################################################################
 # In many cases, dealing with RGB values may not be ideal. Because of that,
@@ -105,7 +104,6 @@ for ax, hue in zip(axes.flat, hue_rotations):
     tinted_image = colorize(image, hue, saturation=0.3)
     ax.imshow(tinted_image, vmin=0, vmax=1)
     ax.set_axis_off()
-    ax.set_adjustable('box-forced')
 fig.tight_layout()
 
 ######################################################################
@@ -134,11 +132,10 @@ textured_regions = noisy > 4
 masked_image = image.copy()
 masked_image[textured_regions, :] *= red_multiplier
 
-fig, (ax1, ax2) = plt.subplots(ncols=2, nrows=1, figsize=(8, 4), sharex=True, sharey=True)
+fig, (ax1, ax2) = plt.subplots(ncols=2, nrows=1, figsize=(8, 4),
+                               sharex=True, sharey=True)
 ax1.imshow(sliced_image)
 ax2.imshow(masked_image)
-ax1.set_adjustable('box-forced')
-ax2.set_adjustable('box-forced')
 
 plt.show()
 
