@@ -28,13 +28,13 @@ is not rocket science.
 .. [1] http://en.wikipedia.org/wiki/Gabor_filter
 .. [2] http://en.wikipedia.org/wiki/Simple_cell
 .. [3] http://en.wikipedia.org/wiki/Receptive_field
-.. [4] http://en.wikipedia.org/wiki/K-means_clustering
-.. [5] http://en.wikipedia.org/wiki/Lateral_geniculate_nucleus
-.. [6] D. H. Hubel and T. N., Wiesel Receptive Fields of Single Neurones
+.. [4] D. H. Hubel and T. N., Wiesel Receptive Fields of Single Neurones
        in the Cat's Striate Cortex, J. Physiol. pp. 574-591 (148) 1959
-.. [7] D. H. Hubel and T. N., Wiesel Receptive Fields, Binocular
+.. [5] D. H. Hubel and T. N., Wiesel Receptive Fields, Binocular
        Interaction, and Functional Architecture in the Cat's Visual Cortex,
        J. Physiol. 160 pp.  106-154 1962
+.. [6] http://en.wikipedia.org/wiki/K-means_clustering
+.. [7] http://en.wikipedia.org/wiki/Lateral_geniculate_nucleus
 """
 import numpy as np
 from scipy.cluster.vq import kmeans2
@@ -44,7 +44,7 @@ import matplotlib.pyplot as plt
 from skimage import data
 from skimage import color
 from skimage.util.shape import view_as_windows
-from skimage.util.montage import montage2d
+from skimage.util import montage
 
 np.random.seed(42)
 
@@ -58,7 +58,7 @@ patches1 = view_as_windows(astro, patch_shape)
 patches1 = patches1.reshape(-1, patch_shape[0] * patch_shape[1])[::8]
 fb1, _ = kmeans2(patches1, n_filters, minit='points')
 fb1 = fb1.reshape((-1,) + patch_shape)
-fb1_montage = montage2d(fb1, rescale_intensity=True)
+fb1_montage = montage(fb1, rescale_intensity=True)
 
 # -- filterbank2 LGN-like image
 astro_dog = ndi.gaussian_filter(astro, .5) - ndi.gaussian_filter(astro, 1)
@@ -66,9 +66,9 @@ patches2 = view_as_windows(astro_dog, patch_shape)
 patches2 = patches2.reshape(-1, patch_shape[0] * patch_shape[1])[::8]
 fb2, _ = kmeans2(patches2, n_filters, minit='points')
 fb2 = fb2.reshape((-1,) + patch_shape)
-fb2_montage = montage2d(fb2, rescale_intensity=True)
+fb2_montage = montage(fb2, rescale_intensity=True)
 
-# --
+# -- plotting
 fig, axes = plt.subplots(2, 2, figsize=(7, 6))
 ax = axes.ravel()
 
