@@ -52,8 +52,8 @@ original = img_as_float(data.chelsea()[100:250, 50:300])
 sigma = 0.155
 noisy = random_noise(original, var=sigma**2)
 
-fig, ax = plt.subplots(nrows=2, ncols=4, figsize=(8, 5), sharex=True,
-                       sharey=True, subplot_kw={'adjustable': 'box-forced'})
+fig, ax = plt.subplots(nrows=2, ncols=4, figsize=(8, 5),
+                       sharex=True, sharey=True)
 
 plt.gray()
 
