@@ -106,8 +106,7 @@ print("Felzenszwalb number of segments: {}".format(len(np.unique(segments_fz))))
 print('SLIC number of segments: {}'.format(len(np.unique(segments_slic))))
 print('Quickshift number of segments: {}'.format(len(np.unique(segments_quick))))
 
-fig, ax = plt.subplots(2, 2, figsize=(10, 10), sharex=True, sharey=True,
-                       subplot_kw={'adjustable': 'box-forced'})
+fig, ax = plt.subplots(2, 2, figsize=(10, 10), sharex=True, sharey=True)
 
 ax[0, 0].imshow(mark_boundaries(img, segments_fz))
 ax[0, 0].set_title("Felzenszwalbs's method")
