@@ -75,8 +75,7 @@ image = data.checkerboard()
 swirled = swirl(image, rotation=0, strength=10, radius=120)
 
 fig, (ax0, ax1) = plt.subplots(nrows=1, ncols=2, figsize=(8, 3),
-                               sharex=True, sharey=True,
-                               subplot_kw={'adjustable':'box-forced'})
+                               sharex=True, sharey=True)
 
 ax0.imshow(image, cmap=plt.cm.gray, interpolation='none')
 ax0.axis('off')
