@@ -105,10 +105,16 @@ def expected_warnings(matching):
     Finally, you can use `|\A\Z` in a pattern to signify it as optional.
 
     """
+    if isinstance(matching, str):
+        raise ValueError('``matching`` should be a list of strings and not '
+                         'a string itself.')
     with all_warnings() as w:
         # enter context
         yield w
         # exited user context, check the recorded warnings
+        # Allow users to provide None
+        while None in matching:
+            matching.remove(None)
         remaining = [m for m in matching if '\A\Z' not in m.split('|')]
         for warn in w:
             found = False
