@@ -120,18 +120,18 @@ def safe_as_int(val, atol=1e-3):
 
     Examples
     --------
-    >>> _safe_as_int(7.0)
+    >>> safe_as_int(7.0)
     7
 
-    >>> _safe_as_int([9, 4, 2.9999999999])
-    array([9, 4, 3], dtype=int32)
+    >>> safe_as_int([9, 4, 2.9999999999])
+    array([9, 4, 3])
 
-    >>> _safe_as_int(53.01)
+    >>> safe_as_int(53.1)
     Traceback (most recent call last):
         ...
     ValueError: Integer argument required but received 53.1, check inputs.
 
-    >>> _safe_as_int(53.01, atol=0.01)
+    >>> safe_as_int(53.01, atol=0.01)
     53
 
     """
