@@ -1,12 +1,13 @@
-from numpy.testing import assert_array_equal, assert_equal, assert_raises, \
-    assert_almost_equal
 import numpy as np
 from skimage._shared.testing import test_parallel
+from skimage._shared import testing
+from skimage._shared.testing import assert_array_equal, assert_equal
+from skimage._shared.testing import assert_almost_equal
 
 from skimage.draw import (set_color, line, line_aa, polygon, polygon_perimeter,
                           circle, circle_perimeter, circle_perimeter_aa,
                           ellipse, ellipse_perimeter,
-                          _bezier_segment, bezier_curve)
+                          _bezier_segment, bezier_curve, rectangle)
 from skimage.measure import regionprops
 
 
@@ -29,7 +30,8 @@ def test_set_color_with_alpha():
     set_color(img, (rr, cc), 1, alpha=alpha)
 
     # Wrong dimensionality color
-    assert_raises(ValueError, set_color, img, (rr, cc), (255, 0, 0), alpha=alpha)
+    with testing.raises(ValueError):
+        set_color(img, (rr, cc), (255, 0, 0), alpha=alpha)
 
     img = np.zeros((10, 10, 3))
 
@@ -548,7 +550,8 @@ def test_ellipse_rotated():
         rr, cc = ellipse(500, 600, 200, 400, rotation=angle)
         img[rr, cc] = 1
         # estimate orientation of ellipse
-        angle_estim = np.round(regionprops(img)[0].orientation, 3) % (np.pi / 2)
+        angle_estim_raw = regionprops(img, coordinates='xy')[0].orientation
+        angle_estim = np.round(angle_estim_raw, 3) % (np.pi / 2)
         assert_almost_equal(angle_estim, angle % (np.pi / 2), 2)
 
 
@@ -851,7 +854,8 @@ def test_polygon_perimeter():
     out[rr, cc] = 1
     assert_array_equal(out, expected)
 
-    assert_raises(ValueError, polygon_perimeter, [0], [1], clip=True)
+    with testing.raises(ValueError):
+        polygon_perimeter([0], [1], clip=True)
 
 
 def test_polygon_perimeter_outside_image():
@@ -861,6 +865,29 @@ def test_polygon_perimeter_outside_image():
     assert_equal(len(cc), 0)
 
 
-if __name__ == "__main__":
-    from numpy.testing import run_module_suite
-    run_module_suite()
+def test_rectangle_end():
+    expected = np.array([[0, 1, 1, 1, 0],
+                         [0, 1, 1, 1, 0],
+                         [0, 1, 1, 1, 0],
+                         [0, 1, 1, 1, 0],
+                         [0, 0, 0, 0, 0]], dtype=np.uint8)
+    img = np.zeros((5, 5), dtype=np.uint8)
+    start = (0, 1)
+    end = (3, 3)
+    rr, cc = rectangle(start, end=end, shape=img.shape)
+    img[rr, cc] = 1
+    assert_array_equal(img, expected)
+
+
+def test_rectangle_extent():
+    expected = np.array([[0, 0, 0, 0, 0],
+                         [0, 1, 1, 1, 0],
+                         [0, 1, 1, 1, 0],
+                         [0, 1, 1, 1, 0],
+                         [0, 0, 0, 0, 0]], dtype=np.uint8)
+    img = np.zeros((5, 5), dtype=np.uint8)
+    start = (1, 1)
+    extent = (3, 3)
+    rr, cc = rectangle(start, extent=extent, shape=img.shape)
+    img[rr, cc] = 1
+    assert_array_equal(img, expected)
