@@ -1,8 +1,7 @@
 from __future__ import division
 import numpy as np
-from .._shared.utils import assert_nD
-from .._shared.utils import skimage_deprecation, warn
 from . import _hoghistogram
+from .._shared.utils import skimage_deprecation, warn
 
 
 def _hog_normalize_block(block, method, eps=1e-5):
@@ -15,30 +14,54 @@ def _hog_normalize_block(block, method, eps=1e-5):
     elif method == 'L2-Hys':
         out = block / np.sqrt(np.sum(block ** 2) + eps ** 2)
         out = np.minimum(out, 0.2)
-        out = out / np.sqrt(np.sum(block ** 2) + eps ** 2)
+        out = out / np.sqrt(np.sum(out ** 2) + eps ** 2)
     else:
         raise ValueError('Selected block normalization method is invalid.')
 
     return out
 
 
+def _hog_channel_gradient(channel):
+    """Compute unnormalized gradient image along `row` and `col` axes.
+
+    Parameters
+    ----------
+    channel : (M, N) ndarray
+        Grayscale image or one of image channel.
+
+    Returns
+    -------
+    g_row, g_col : channel gradient along `row` and `col` axes correspondingly.
+    """
+    g_row = np.empty(channel.shape, dtype=np.double)
+    g_row[0, :] = 0
+    g_row[-1, :] = 0
+    g_row[1:-1, :] = channel[2:, :] - channel[:-2, :]
+    g_col = np.empty(channel.shape, dtype=np.double)
+    g_col[:, 0] = 0
+    g_col[:, -1] = 0
+    g_col[:, 1:-1] = channel[:, 2:] - channel[:, :-2]
+
+    return g_row, g_col
+
+
 def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
-        block_norm='L1', visualise=False, transform_sqrt=False,
-        feature_vector=True, normalise=None):
+        block_norm=None, visualize=False, visualise=None, transform_sqrt=False,
+        feature_vector=True, multichannel=None):
     """Extract Histogram of Oriented Gradients (HOG) for a given image.
 
     Compute a Histogram of Oriented Gradients (HOG) by
 
         1. (optional) global image normalization
-        2. computing the gradient image in x and y
+        2. computing the gradient image in `row` and `col`
         3. computing gradient histograms
         4. normalizing across blocks
         5. flattening into a feature vector
 
     Parameters
     ----------
-    image : (M, N) ndarray
-        Input image (greyscale).
+    image : (M, N[, C]) ndarray
+        Input image.
     orientations : int, optional
         Number of orientation bins.
     pixels_per_cell : 2-tuple (int, int), optional
@@ -60,8 +83,12 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
            renormalization using L2-norm.
            For details, see [3]_, [4]_.
 
-    visualise : bool, optional
-        Also return an image of the HOG.
+    visualize : bool, optional
+        Also return an image of the HOG.  For each cell and orientation bin,
+        the image contains a line segment that is centered at the cell center,
+        is perpendicular to the midpoint of the range of angles spanned by the
+        orientation bin, and has intensity proportional to the corresponding
+        histogram value.
     transform_sqrt : bool, optional
         Apply power law compression to normalize the image before
         processing. DO NOT use this if the image contains negative
@@ -69,16 +96,17 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
     feature_vector : bool, optional
         Return the data as a feature vector by calling .ravel() on the result
         just before returning.
-    normalise : bool, deprecated
-        The parameter is deprecated. Use `transform_sqrt` for power law
-        compression. `normalise` has been deprecated.
+    multichannel : boolean, optional
+        If True, the last `image` dimension is considered as a color channel,
+        otherwise as spatial.
 
     Returns
     -------
-    newarr : ndarray
-        HOG for the image as a 1D (flattened) array.
-    hog_image : ndarray (if visualise=True)
-        A visualisation of the HOG image.
+    out : (n_blocks_row, n_blocks_col, n_cells_row, n_cells_col, n_orient) ndarray
+        HOG descriptor for the image. If `feature_vector` is True, a 1D
+        (flattened) array is returned.
+    hog_image : (M, N) ndarray, optional
+        A visualisation of the HOG image. Only provided if `visualize` is True.
 
     References
     ----------
@@ -114,32 +142,34 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
     and then applies the hog algorithm to the image.
     """
 
-    if block_norm == 'L1':
+    if block_norm is None:
+        block_norm = 'L1'
         warn('Default value of `block_norm`==`L1` is deprecated and will '
-             'be changed to `L2-Hys` in v0.15', skimage_deprecation)
+             'be changed to `L2-Hys` in v0.15. To supress this message '
+             'specify explicitly the normalization method.',
+             skimage_deprecation)
 
     image = np.atleast_2d(image)
 
+    if multichannel is None:
+        multichannel = (image.ndim == 3)
+
+    ndim_spatial = image.ndim - 1 if multichannel else image.ndim
+    if ndim_spatial != 2:
+        raise ValueError('Only images with 2 spatial dimensions are '
+                         'supported. If using with color/multichannel '
+                         'images, specify `multichannel=True`.')
+
     """
     The first stage applies an optional global image normalization
     equalisation that is designed to reduce the influence of illumination
     effects. In practice we use gamma (power law) compression, either
-    computing the square root or the log of each colour channel.
+    computing the square root or the log of each color channel.
     Image texture strength is typically proportional to the local surface
     illumination so this compression helps to reduce the effects of local
     shadowing and illumination variations.
     """
 
-    assert_nD(image, 2)
-
-    if normalise is not None:
-        raise ValueError("The ``normalise`` parameter was removed due to "
-                         "incorrect behavior: it only applied a square root "
-                         "instead of a true normalization. "
-                         "If you wish to duplicate the old behavior, set "
-                         "``transform_sqrt=True``. ``normalise`` will be "
-                         "completely removed in v0.14.")
-
     if transform_sqrt:
         image = np.sqrt(image)
 
@@ -147,7 +177,7 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
     The second stage computes first order image gradients. These capture
     contour, silhouette and some texture information, while providing
     further resistance to illumination variations. The locally dominant
-    colour channel is used, which provides colour invariance to a large
+    color channel is used, which provides color invariance to a large
     extent. Variant methods may also include second order image derivatives,
     which act as primitive bar detectors - a useful feature for capturing,
     e.g. bar like structures in bicycles and limbs in humans.
@@ -158,8 +188,27 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
         # to avoid problems with subtracting unsigned numbers
         image = image.astype('float')
 
-    gy, gx = [np.ascontiguousarray(g, dtype=np.double)
-              for g in np.gradient(image)]
+    if multichannel:
+        g_row_by_ch = np.empty_like(image, dtype=np.double)
+        g_col_by_ch = np.empty_like(image, dtype=np.double)
+        g_magn = np.empty_like(image, dtype=np.double)
+
+        for idx_ch in range(image.shape[2]):
+            g_row_by_ch[:, :, idx_ch], g_col_by_ch[:, :, idx_ch] = \
+                _hog_channel_gradient(image[:, :, idx_ch])
+            g_magn[:, :, idx_ch] = np.hypot(g_row_by_ch[:, :, idx_ch],
+                                            g_col_by_ch[:, :, idx_ch])
+
+        # For each pixel select the channel with the highest gradient magnitude
+        idcs_max = g_magn.argmax(axis=2)
+        rr, cc = np.meshgrid(np.arange(image.shape[0]),
+                             np.arange(image.shape[1]),
+                             indexing='ij',
+                             sparse=True)
+        g_row = g_row_by_ch[rr, cc, idcs_max]
+        g_col = g_col_by_ch[rr, cc, idcs_max]
+    else:
+        g_row, g_col = _hog_channel_gradient(image)
 
     """
     The third stage aims to produce an encoding that is sensitive to
@@ -176,39 +225,48 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
     cell are used to vote into the orientation histogram.
     """
 
-    sy, sx = image.shape
-    cx, cy = pixels_per_cell
-    bx, by = cells_per_block
+    s_row, s_col = image.shape[:2]
+    c_row, c_col = pixels_per_cell
+    b_row, b_col = cells_per_block
 
-    n_cellsx = int(sx // cx)  # number of cells in x
-    n_cellsy = int(sy // cy)  # number of cells in y
+    n_cells_row = int(s_row // c_row)  # number of cells along row-axis
+    n_cells_col = int(s_col // c_col)  # number of cells along col-axis
 
     # compute orientations integral images
-    orientation_histogram = np.zeros((n_cellsy, n_cellsx, orientations))
+    orientation_histogram = np.zeros((n_cells_row, n_cells_col, orientations))
 
-    _hoghistogram.hog_histograms(gx, gy, cx, cy, sx, sy, n_cellsx, n_cellsy,
+    _hoghistogram.hog_histograms(g_col, g_row, c_col, c_row, s_col, s_row,
+                                 n_cells_col, n_cells_row,
                                  orientations, orientation_histogram)
 
     # now compute the histogram for each cell
     hog_image = None
 
-    if visualise:
+    if visualise is not None:
+        visualize = visualise
+        warn('Argument `visualise` is deprecated and will '
+             'be changed to `visualize` in v0.16', skimage_deprecation)
+    if visualize:
         from .. import draw
 
-        radius = min(cx, cy) // 2 - 1
+        radius = min(c_row, c_col) // 2 - 1
         orientations_arr = np.arange(orientations)
-        dx_arr = radius * np.cos(orientations_arr / orientations * np.pi)
-        dy_arr = radius * np.sin(orientations_arr / orientations * np.pi)
-        hog_image = np.zeros((sy, sx), dtype=float)
-        for x in range(n_cellsx):
-            for y in range(n_cellsy):
-                for o, dx, dy in zip(orientations_arr, dx_arr, dy_arr):
-                    centre = tuple([y * cy + cy // 2, x * cx + cx // 2])
-                    rr, cc = draw.line(int(centre[0] - dx),
-                                       int(centre[1] + dy),
-                                       int(centre[0] + dx),
-                                       int(centre[1] - dy))
-                    hog_image[rr, cc] += orientation_histogram[y, x, o]
+        # set dr_arr, dc_arr to correspond to midpoints of orientation bins
+        orientation_bin_midpoints = (
+            np.pi * (orientations_arr + .5) / orientations)
+        dr_arr = radius * np.sin(orientation_bin_midpoints)
+        dc_arr = radius * np.cos(orientation_bin_midpoints)
+        hog_image = np.zeros((s_row, s_col), dtype=float)
+        for r in range(n_cells_row):
+            for c in range(n_cells_col):
+                for o, dr, dc in zip(orientations_arr, dr_arr, dc_arr):
+                    centre = tuple([r * c_row + c_row // 2,
+                                    c * c_col + c_col // 2])
+                    rr, cc = draw.line(int(centre[0] - dc),
+                                       int(centre[1] + dr),
+                                       int(centre[0] + dc),
+                                       int(centre[1] - dr))
+                    hog_image[rr, cc] += orientation_histogram[r, c, o]
 
     """
     The fourth stage computes normalization, which takes local groups of
@@ -225,15 +283,15 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
     Gradient (HOG) descriptors.
     """
 
-    n_blocksx = (n_cellsx - bx) + 1
-    n_blocksy = (n_cellsy - by) + 1
-    normalized_blocks = np.zeros((n_blocksy, n_blocksx,
-                                  by, bx, orientations))
+    n_blocks_row = (n_cells_row - b_row) + 1
+    n_blocks_col = (n_cells_col - b_col) + 1
+    normalized_blocks = np.zeros((n_blocks_row, n_blocks_col,
+                                  b_row, b_col, orientations))
 
-    for x in range(n_blocksx):
-        for y in range(n_blocksy):
-            block = orientation_histogram[y:y + by, x:x + bx, :]
-            normalized_blocks[y, x, :] = \
+    for r in range(n_blocks_row):
+        for c in range(n_blocks_col):
+            block = orientation_histogram[r:r + b_row, c:c + b_col, :]
+            normalized_blocks[r, c, :] = \
                 _hog_normalize_block(block, method=block_norm)
 
     """
@@ -245,7 +303,7 @@ def hog(image, orientations=9, pixels_per_cell=(8, 8), cells_per_block=(3, 3),
     if feature_vector:
         normalized_blocks = normalized_blocks.ravel()
 
-    if visualise:
+    if visualize:
         return normalized_blocks, hog_image
     else:
         return normalized_blocks
