@@ -19,6 +19,7 @@ def configuration(parent_package='', top_path=None):
     cython(['_texture.pyx'], working_path=base_path)
     cython(['_hessian_det_appx.pyx'], working_path=base_path)
     cython(['_hoghistogram.pyx'], working_path=base_path)
+    cython(['_haar.pyx'], working_path=base_path)
 
     config.add_extension('corner_cy', sources=['corner_cy.c'],
                          include_dirs=[get_numpy_include_dirs()])
@@ -34,6 +35,9 @@ def configuration(parent_package='', top_path=None):
                          include_dirs=[get_numpy_include_dirs()])
     config.add_extension('_hoghistogram', sources=['_hoghistogram.c'],
                          include_dirs=[get_numpy_include_dirs(), '../_shared'])
+    config.add_extension('_haar', sources=['_haar.cpp'],
+                         include_dirs=[get_numpy_include_dirs(), '../_shared'],
+                         language="c++")
 
     return config
 
