@@ -1,6 +1,7 @@
 import os
 import numpy as np
-from numpy.testing import run_module_suite, assert_equal, assert_raises
+from skimage._shared.testing import assert_equal
+from skimage._shared import testing
 
 import skimage
 from skimage import img_as_ubyte, img_as_float
@@ -8,7 +9,7 @@ from skimage import data, util, morphology
 from skimage.morphology import grey, disk
 from skimage.filters import rank
 from skimage._shared._warnings import expected_warnings
-from skimage._shared.testing import test_parallel
+from skimage._shared.testing import test_parallel, xfail, arch32
 
 
 class TestRank():
@@ -20,6 +21,11 @@ class TestRank():
         # Set again the seed for the other tests.
         np.random.seed(0)
 
+    @xfail(condition=arch32,
+           reason=('Known test failure on 32-bit platforms. See links for '
+                   'details: '
+                   'https://github.com/scikit-image/scikit-image/issues/3091 '
+                   'https://github.com/scikit-image/scikit-image/issues/2528'))
     def test_all(self):
         @test_parallel()
         def check_all():
@@ -252,7 +258,8 @@ class TestRank():
         selem = disk(20)
         image = (np.random.rand(500, 500) * 256).astype(np.uint8)
         out = image
-        assert_raises(NotImplementedError, rank.mean, image, selem, out=out)
+        with testing.raises(NotImplementedError):
+            rank.mean(image, selem, out=out)
 
 
     def test_compare_autolevels(self):
@@ -725,7 +732,3 @@ class TestRank():
         assert_equal(rank.median(a), rank.median(a, full_selem))
         assert rank.median(a)[1, 1] == 0
         assert rank.median(a, disk(1))[1, 1] == 1
-
-
-if __name__ == "__main__":
-    run_module_suite()
