@@ -1,9 +1,8 @@
 import numpy as np
 from skimage.future import graph
 from skimage._shared.version_requirements import is_installed
-from numpy.testing.decorators import skipif
 from skimage import segmentation
-from numpy import testing
+from skimage._shared import testing
 
 
 def max_edge(g, src, dst, n):
@@ -13,7 +12,8 @@ def max_edge(g, src, dst, n):
     return {'weight': max(w1, w2)}
 
 
-@skipif(not is_installed('networkx'))
+@testing.skipif(not is_installed('networkx'),
+                reason="networkx not installed")
 def test_rag_merge():
     g = graph.rag.RAG()
 
@@ -48,7 +48,8 @@ def test_rag_merge():
     assert list(g.edges()) == []
 
 
-@skipif(not is_installed('networkx'))
+@testing.skipif(not is_installed('networkx'),
+                reason="networkx not installed")
 def test_threshold_cut():
 
     img = np.zeros((100, 100, 3), dtype='uint8')
@@ -73,7 +74,8 @@ def test_threshold_cut():
     assert new_labels.max() == 1
 
 
-@skipif(not is_installed('networkx'))
+@testing.skipif(not is_installed('networkx'),
+                reason="networkx not installed")
 def test_cut_normalized():
 
     img = np.zeros((100, 100, 3), dtype='uint8')
@@ -100,14 +102,16 @@ def test_cut_normalized():
     assert new_labels.max() == 1
 
 
-@skipif(not is_installed('networkx'))
+@testing.skipif(not is_installed('networkx'),
+                reason="networkx not installed")
 def test_rag_error():
     img = np.zeros((10, 10, 3), dtype='uint8')
     labels = np.zeros((10, 10), dtype='uint8')
     labels[:5, :] = 0
     labels[5:, :] = 1
-    testing.assert_raises(ValueError, graph.rag_mean_color, img, labels,
-                          2, 'non existant mode')
+    with testing.raises(ValueError):
+        graph.rag_mean_color(img, labels,
+                             2, 'non existant mode')
 
 
 def _weight_mean_color(graph, src, dst, n):
@@ -130,7 +134,8 @@ def merge_hierarchical_mean_color(labels, rag, thresh, rag_copy=True,
                                     _weight_mean_color)
 
 
-@skipif(not is_installed('networkx'))
+@testing.skipif(not is_installed('networkx'),
+                reason="networkx not installed")
 def test_rag_hierarchical():
     img = np.zeros((8, 8, 3), dtype='uint8')
     labels = np.zeros((8, 8), dtype='uint8')
@@ -161,7 +166,8 @@ def test_rag_hierarchical():
     assert np.all(result == result[0, 0])
 
 
-@skipif(not is_installed('networkx'))
+@testing.skipif(not is_installed('networkx'),
+                reason="networkx not installed")
 def test_ncut_stable_subgraph():
     """ Test to catch an error thrown when subgraph has all equal edges. """
 
