@@ -1,17 +1,16 @@
 import os
-
-import numpy as np
-from numpy.testing import assert_raises, assert_equal, assert_allclose
-
-from skimage.io import use_plugin
-from skimage import data_dir
-from skimage.io.collection import MultiImage, ImageCollection
-
 import six
 
+import numpy as np
+from skimage import data_dir
+from skimage.io import use_plugin
+from skimage.io.collection import MultiImage, ImageCollection
 
-class TestMultiImage():
+from skimage._shared import testing
+from skimage._shared.testing import assert_equal, assert_allclose, TestCase
 
+
+class TestMultiImage(TestCase):
     def setUp(self):
         # This multipage TIF file was created with imagemagick:
         # convert im1.tif im2.tif -adjoin multipage.tif
@@ -58,15 +57,13 @@ class TestMultiImage():
                 assert type(img[i]) is np.ndarray
             assert_allclose(img[0], img[-num])
 
-            assert_raises(AssertionError,
-                          assert_allclose,
-                          img[0], img[1])
+            with testing.raises(AssertionError):
+                assert_allclose(img[0], img[1])
 
-            # assert_raises expects a callable, hence this thin wrapper function.
-            def return_img(n):
-                return img[n]
-            assert_raises(IndexError, return_img, num)
-            assert_raises(IndexError, return_img, -num - 1)
+            with testing.raises(IndexError):
+                img[num]
+            with testing.raises(IndexError):
+                img[-num - 1]
 
     def test_files_property(self):
         for img in self.imgs:
@@ -75,27 +72,21 @@ class TestMultiImage():
 
             assert isinstance(img.filename, six.string_types)
 
-            def set_filename(f):
-                img.filename = f
-            assert_raises(AttributeError, set_filename, 'newfile')
+            with testing.raises(AttributeError):
+                img.filename = "newfile"
 
     def test_conserve_memory_property(self):
         for img in self.imgs:
             assert isinstance(img.conserve_memory, bool)
 
-            def set_mem(val):
-                img.conserve_memory = val
-            assert_raises(AttributeError, set_mem, True)
+            with testing.raises(AttributeError):
+                img.conserve_memory = True
 
     def test_concatenate(self):
         for img in self.imgs:
             if img[0].shape != img[-1].shape:
-                assert_raises(ValueError, img.concatenate)
+                with testing.raises(ValueError):
+                    img.concatenate()
                 continue
             array = img.concatenate()
             assert_equal(array.shape, (len(img),) + img[0].shape)
-
-
-if __name__ == "__main__":
-    from numpy.testing import run_module_suite
-    run_module_suite()
