@@ -1,12 +1,13 @@
 import os
+import itertools
+from tempfile import NamedTemporaryFile
 from ... import data_dir
 from .. import imread, imsave, use_plugin, reset_plugins
 import numpy as np
 
-from numpy.testing import (
-    assert_array_equal, assert_array_almost_equal, run_module_suite)
-
-from tempfile import NamedTemporaryFile
+from skimage._shared.testing import (assert_array_equal,
+                                     assert_array_almost_equal,
+                                     parametrize)
 
 
 def setup():
@@ -46,18 +47,15 @@ class TestSave:
         y = imread(fname)
         assert_array_equal(x, y)
 
-    def test_imsave_roundtrip(self):
-        for shape in [(10, 10), (10, 10, 3), (10, 10, 4)]:
-            for dtype in (np.uint8, np.uint16, np.float32, np.int16,
-                          np.float64):
-                x = np.random.rand(*shape)
+    shapes = ((10, 10), (10, 10, 3), (10, 10, 4))
+    dtypes = (np.uint8, np.uint16, np.float32, np.int16, np.float64)
 
-                if not np.issubdtype(dtype, float):
-                    x = (x * np.iinfo(dtype).max).astype(dtype)
-                else:
-                    x = x.astype(dtype)
-                yield self.roundtrip, dtype, x
+    @parametrize("shape, dtype", itertools.product(shapes, dtypes))
+    def test_imsave_roundtrip(self, shape, dtype):
+        x = np.random.rand(*shape)
 
-
-if __name__ == "__main__":
-    run_module_suite()
+        if not np.issubdtype(dtype, np.floating):
+            x = (x * np.iinfo(dtype).max).astype(dtype)
+        else:
+            x = x.astype(dtype)
+        self.roundtrip(dtype, x)
