@@ -1,19 +1,24 @@
 """Convex Hull."""
+from itertools import product
 import numpy as np
+from scipy.spatial import ConvexHull
 from ..measure.pnpoly import grid_points_in_poly
 from ._convex_hull import possible_hull
 from ..measure._label import label
 from ..util import unique_rows
+from .._shared.utils import warn
 
 __all__ = ['convex_hull_image', 'convex_hull_object']
 
-try:
-    from scipy.spatial import Delaunay
-except ImportError:
-    Delaunay = None
+
+def _offsets_diamond(ndim):
+    offsets = np.zeros((2 * ndim, ndim))
+    for vertex, (axis, offset) in enumerate(product(range(ndim), (-0.5, 0.5))):
+        offsets[vertex, axis] = offset
+    return offsets
 
 
-def convex_hull_image(image):
+def convex_hull_image(image, offset_coordinates=True, tolerance=1e-10):
     """Compute the convex hull image of a binary image.
 
     The convex hull is the set of pixels included in the smallest convex
@@ -21,8 +26,16 @@ def convex_hull_image(image):
 
     Parameters
     ----------
-    image : (M, N) array
+    image : array
         Binary input image. This array is cast to bool before processing.
+    offset_coordinates : bool, optional
+        If ``True``, a pixel at coordinate, e.g., (4, 7) will be represented
+        by coordinates (3.5, 7), (4.5, 7), (4, 6.5), and (4, 7.5). This adds
+        some "extent" to a pixel when computing the hull.
+    tolerance : float, optional
+        Tolerance when determining whether a point is inside the hull. Due
+        to numerical floating point errors, a tolerance of 0 can result in
+        some points erroneously being classified as being outside the hull.
 
     Returns
     -------
@@ -34,48 +47,48 @@ def convex_hull_image(image):
     .. [1] http://blogs.mathworks.com/steve/2011/10/04/binary-image-convex-hull-algorithm-notes/
 
     """
-    if image.ndim > 2:
-        raise ValueError("Input must be a 2D image")
-
-    if Delaunay is None:
-        raise ImportError("Could not import scipy.spatial.Delaunay, "
-                          "only available in scipy >= 0.9.")
-
-    # Here we do an optimisation by choosing only pixels that are
+    ndim = image.ndim
+    if np.count_nonzero(image) == 0:
+        warn("Input image is entirely zero, no valid convex hull. "
+             "Returning empty image", UserWarning)
+        return np.zeros(image.shape, dtype=np.bool_)
+    # In 2D, we do an optimisation by choosing only pixels that are
     # the starting or ending pixel of a row or column.  This vastly
     # limits the number of coordinates to examine for the virtual hull.
-    coords = possible_hull(image.astype(np.uint8))
-    N = len(coords)
+    if ndim == 2:
+        coords = possible_hull(image.astype(np.uint8))
+    else:
+        coords = np.transpose(np.nonzero(image))
+        if offset_coordinates:
+            # when offsetting, we multiply number of vertices by 2 * ndim.
+            # therefore, we reduce the number of coordinates by using a
+            # convex hull on the original set, before offsetting.
+            hull0 = ConvexHull(coords)
+            coords = hull0.points[hull0.vertices]
 
     # Add a vertex for the middle of each pixel edge
-    coords_corners = np.empty((N * 4, 2))
-    for i, (x_offset, y_offset) in enumerate(zip((0, 0, -0.5, 0.5),
-                                                 (-0.5, 0.5, 0, 0))):
-        coords_corners[i * N:(i + 1) * N] = coords + [x_offset, y_offset]
+    if offset_coordinates:
+        offsets = _offsets_diamond(image.ndim)
+        coords = (coords[:, np.newaxis, :] + offsets).reshape(-1, ndim)
 
     # repeated coordinates can *sometimes* cause problems in
-    # scipy.spatial.Delaunay, so we remove them.
-    coords = unique_rows(coords_corners)
-
-    # Subtract offset
-    offset = coords.mean(axis=0)
-    coords -= offset
+    # scipy.spatial.ConvexHull, so we remove them.
+    coords = unique_rows(coords)
 
     # Find the convex hull
-    chull = Delaunay(coords).convex_hull
-    v = coords[np.unique(chull)]
+    hull = ConvexHull(coords)
+    vertices = hull.points[hull.vertices]
 
-    # Sort vertices clock-wise
-    v_centred = v - v.mean(axis=0)
-    angles = np.arctan2(v_centred[:, 0], v_centred[:, 1])
-    v = v[np.argsort(angles)]
-
-    # Add back offset
-    v += offset
-
-    # For each pixel coordinate, check whether that pixel
-    # lies inside the convex hull
-    mask = grid_points_in_poly(image.shape[:2], v)
+    # If 2D, use fast Cython function to locate convex hull pixels
+    if ndim == 2:
+        mask = grid_points_in_poly(image.shape, vertices)
+    else:
+        gridcoords = np.reshape(np.mgrid[tuple(map(slice, image.shape))],
+                                (ndim, -1))
+        # A point is in the hull if it satisfies all of the hull's inequalities
+        coords_in_hull = np.all(hull.equations[:, :ndim].dot(gridcoords) +
+                                hull.equations[:, ndim:] < tolerance, axis=0)
+        mask = np.reshape(coords_in_hull, image.shape)
 
     return mask
 
