@@ -17,6 +17,7 @@ def configuration(parent_package='', top_path=None):
     cython(['_convex_hull.pyx'], working_path=base_path)
     cython(['_greyreconstruct.pyx'], working_path=base_path)
     cython(['_skeletonize_3d_cy.pyx.in'], working_path=base_path)
+    cython(['_extrema_cy.pyx'], working_path=base_path)
 
     config.add_extension('_watershed', sources=['_watershed.c'],
                          include_dirs=[get_numpy_include_dirs()])
@@ -28,6 +29,8 @@ def configuration(parent_package='', top_path=None):
                          include_dirs=[get_numpy_include_dirs()])
     config.add_extension('_skeletonize_3d_cy', sources=['_skeletonize_3d_cy.c'],
                          include_dirs=[get_numpy_include_dirs()])
+    config.add_extension('_extrema_cy', sources=['_extrema_cy.c'],
+                         include_dirs=[get_numpy_include_dirs()])
 
     return config
 
