@@ -2,14 +2,17 @@ import os
 import tempfile
 
 import numpy as np
-from nose.tools import assert_true
-from numpy.testing import assert_equal, raises, assert_allclose
 from skimage import novice
 from skimage.novice._novice import (array_to_xy_origin, xy_to_array_origin,
                                     rgb_transpose)
 from skimage import data_dir
+
+from skimage._shared import testing
+from skimage._shared.testing import (assert_equal, assert_allclose,
+                                     expected_warnings)
 from skimage._shared.utils import all_warnings
 
+
 IMAGE_PATH = os.path.join(data_dir, "chelsea.png")
 SMALL_IMAGE_PATH = os.path.join(data_dir, "block.png")
 
@@ -95,7 +98,8 @@ def test_pixel_rgba():
     pixel.rgba = np.arange(4)
 
     assert_equal(pixel.rgba, np.arange(4))
-    for i, channel in enumerate((pixel.red, pixel.green, pixel.blue, pixel.alpha)):
+    pixel_channels = (pixel.red, pixel.green, pixel.blue, pixel.alpha)
+    for i, channel in enumerate(pixel_channels):
         assert_equal(channel, i)
 
     pixel.red = 3
@@ -104,7 +108,8 @@ def test_pixel_rgba():
     pixel.alpha = 6
     assert_equal(pixel.rgba, np.arange(4) + 3)
 
-    for i, channel in enumerate((pixel.red, pixel.green, pixel.blue, pixel.alpha)):
+    pixel_channels = (pixel.red, pixel.green, pixel.blue, pixel.alpha)
+    for i, channel in enumerate(pixel_channels):
         assert_equal(channel, i + 3)
 
 
@@ -141,30 +146,42 @@ def test_reset():
     v = pic[0, 0]
     pic[0, 0] = (1, 1, 1)
     pic.reset()
-    assert_true(pic[0, 0] == v)
+    assert pic[0, 0] == v
 
 
 def test_update_on_save():
     pic = novice.Picture(array=np.zeros((3, 3, 3)))
-    pic[0, 0] = (255, 255, 255)  # prevent attempting to save low-contrast image
+    # prevent attempting to save low-contrast image
+    pic[0, 0] = (255, 255, 255)
 
     with all_warnings():  # precision loss
         pic.size = (6, 6)
     assert pic.modified
     assert pic.path is None
 
-    fd, filename = tempfile.mkstemp(suffix=".jpg")
+    fd, filename = tempfile.mkstemp(suffix=".png")
     os.close(fd)
     try:
         pic.save(filename)
 
         assert not pic.modified
         assert_equal(pic.path, os.path.abspath(filename))
-        assert_equal(pic.format, "jpeg")
+        assert_equal(pic.format, "png")
     finally:
         os.unlink(filename)
 
 
+def test_save_with_alpha_channel():
+    # create an image with an alpha channel
+    pic = novice.Picture(array=np.zeros((3, 3, 4)))
+
+    fd, filename = tempfile.mkstemp(suffix=".png")
+    os.close(fd)
+    with expected_warnings(['is a low contrast']):
+        pic.save(filename)
+    os.unlink(filename)
+
+
 def test_indexing():
     array = 128 * np.ones((10, 10, 3), dtype=np.uint8)
     pic = novice.Picture(array=array)
@@ -259,65 +276,61 @@ def test_getitem_with_step():
     assert sliced_pic == novice.Picture(array=array[::2, ::2])
 
 
-@raises(IndexError)
 def test_1d_getitem_raises():
     pic = novice.Picture.from_size((1, 1))
-    pic[1]
+    with testing.raises(IndexError):
+        pic[1]
 
 
-@raises(IndexError)
 def test_3d_getitem_raises():
     pic = novice.Picture.from_size((1, 1))
-    pic[1, 2, 3]
+    with testing.raises(IndexError):
+        pic[1, 2, 3]
 
 
-@raises(IndexError)
 def test_1d_setitem_raises():
     pic = novice.Picture.from_size((1, 1))
-    pic[1] = 0
+    with testing.raises(IndexError):
+        pic[1] = 0
 
 
-@raises(IndexError)
 def test_3d_setitem_raises():
     pic = novice.Picture.from_size((1, 1))
-    pic[1, 2, 3] = 0
+    with testing.raises(IndexError):
+        pic[1, 2, 3] = 0
 
 
-@raises(IndexError)
 def test_out_of_bounds_indexing():
     pic = novice.open(SMALL_IMAGE_PATH)
-    pic[pic.width, pic.height]
+    with testing.raises(IndexError):
+        pic[pic.width, pic.height]
 
 
-@raises(ValueError)
 def test_pixel_rgb_raises():
     pixel = novice.Picture.from_size((1, 1))[0, 0]
-    pixel.rgb = (-1, -1, -1)
+    with testing.raises(ValueError):
+        pixel.rgb = (-1, -1, -1)
 
 
-@raises(ValueError)
 def test_pixel_red_raises():
     pixel = novice.Picture.from_size((1, 1))[0, 0]
-    pixel.red = 256
+    with testing.raises(ValueError):
+        pixel.red = 256
 
 
-@raises(ValueError)
 def test_pixel_green_raises():
     pixel = novice.Picture.from_size((1, 1))[0, 0]
-    pixel.green = 256
+    with testing.raises(ValueError):
+        pixel.green = 256
 
 
-@raises(ValueError)
 def test_pixel_blue_raises():
     pixel = novice.Picture.from_size((1, 1))[0, 0]
-    pixel.blue = 256
+    with testing.raises(ValueError):
+        pixel.blue = 256
 
 
-@raises(ValueError)
 def test_pixel_alpha_raises():
     pixel = novice.Picture.from_size((1, 1))[0, 0]
-    pixel.alpha = 256
-
-
-if __name__ == '__main__':
-    np.testing.run_module_suite()
+    with testing.raises(ValueError):
+        pixel.alpha = 256
