@@ -7,7 +7,7 @@ from __future__ import division
 
 import numpy as np
 import numpy.random as npr
-from scipy.signal import convolve2d
+from scipy.signal import fftconvolve, convolve
 
 from . import uft
 
@@ -36,11 +36,11 @@ def wiener(image, psf, balance, reg=None, is_real=True, clip=True):
        The regularisation parameter value that tunes the balance
        between the data adequacy that improve frequency restoration
        and the prior adequacy that reduce frequency restoration (to
-       avoid noise artifact).
+       avoid noise artifacts).
     reg : ndarray, optional
        The regularisation operator. The Laplacian by default. It can
        be an impulse response or a transfer function, as for the
-       psf. Shape constraint is the same than for the `psf` parameter.
+       psf. Shape constraint is the same as for the `psf` parameter.
     is_real : boolean, optional
        True by default. Specify if ``psf`` and ``reg`` are provided
        with hermitian hypothesis, that is only half of the frequency
@@ -49,24 +49,23 @@ def wiener(image, psf, balance, reg=None, is_real=True, clip=True):
        provided as transfer function.  For the hermitian property see
        ``uft`` module or ``np.fft.rfftn``.
     clip : boolean, optional
-       True by default. If true, pixel value of the result above 1 or
-       under -1 are thresholded for skimage pipeline
-       compatibility.
+       True by default. If True, pixel values of the result above 1 or
+       under -1 are thresholded for skimage pipeline compatibility.
 
     Returns
     -------
     im_deconv : (M, N) ndarray
-       The deconvolved image
+       The deconvolved image.
 
     Examples
     --------
     >>> from skimage import color, data, restoration
-    >>> lena = color.rgb2gray(data.lena())
+    >>> img = color.rgb2gray(data.astronaut())
     >>> from scipy.signal import convolve2d
     >>> psf = np.ones((5, 5)) / 25
-    >>> lena = convolve2d(lena, psf, 'same')
-    >>> lena += 0.1 * lena.std() * np.random.standard_normal(lena.shape)
-    >>> deconvolved_lena = restoration.wiener(lena, psf, 1100)
+    >>> img = convolve2d(img, psf, 'same')
+    >>> img += 0.1 * img.std() * np.random.standard_normal(img.shape)
+    >>> deconvolved_img = restoration.wiener(img, psf, 1100)
 
     Notes
     -----
@@ -79,10 +78,10 @@ def wiener(image, psf, balance, reg=None, is_real=True, clip=True):
     unknown original image, the Wiener filter is
 
     .. math::
-       \hat x = F^\dag (|\Lambda_H|^2 + \lambda |\Lambda_D|^2)
-       \Lambda_H^\dag F y
+       \hat x = F^\dagger (|\Lambda_H|^2 + \lambda |\Lambda_D|^2)
+       \Lambda_H^\dagger F y
 
-    where :math:`F` and :math:`F^\dag` are the Fourier and inverse
+    where :math:`F` and :math:`F^\dagger` are the Fourier and inverse
     Fourier transfroms respectively, :math:`\Lambda_H` the transfer
     function (or the Fourier transfrom of the PSF, see [Hunt] below)
     and :math:`\Lambda_D` the filter to penalize the restored image
@@ -96,8 +95,8 @@ def wiener(image, psf, balance, reg=None, is_real=True, clip=True):
     prior model. By default, the prior model (Laplacian) introduce
     image smoothness or pixel correlation. It can also be interpreted
     as high-frequency penalization to compensate the instability of
-    the solution wrt. data (sometimes called noise amplification or
-    "explosive" solution).
+    the solution with respect to the data (sometimes called noise
+    amplification or "explosive" solution).
 
     Finally, the use of Fourier space implies a circulant property of
     :math:`H`, see [Hunt].
@@ -127,10 +126,11 @@ def wiener(image, psf, balance, reg=None, is_real=True, clip=True):
     else:
         trans_func = psf
 
-    wiener_filter = np.conj(trans_func) / (np.abs(trans_func)**2 +
-                                           balance * np.abs(reg)**2)
+    wiener_filter = np.conj(trans_func) / (np.abs(trans_func) ** 2 +
+                                           balance * np.abs(reg) ** 2)
     if is_real:
-        deconv = uft.uirfft2(wiener_filter * uft.urfft2(image))
+        deconv = uft.uirfft2(wiener_filter * uft.urfft2(image),
+                             shape=image.shape)
     else:
         deconv = uft.uifft2(wiener_filter * uft.ufft2(image))
 
@@ -143,7 +143,7 @@ def wiener(image, psf, balance, reg=None, is_real=True, clip=True):
 
 def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
                         clip=True):
-    """Unsupervised Wiener-Hunt deconvolution
+    """Unsupervised Wiener-Hunt deconvolution.
 
     Return the deconvolution with a Wiener-Hunt approach, where the
     hyperparameters are automatically estimated. The algorithm is a
@@ -153,21 +153,20 @@ def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
     Parameters
     ----------
     image : (M, N) ndarray
-       The input degraded image
+       The input degraded image.
     psf : ndarray
        The impulse response (input image's space) or the transfer
        function (Fourier space). Both are accepted. The transfer
-       function is recognize as being complex
+       function is automatically recognized as being complex
        (``np.iscomplexobj(psf)``).
     reg : ndarray, optional
        The regularisation operator. The Laplacian by default. It can
        be an impulse response or a transfer function, as for the psf.
     user_params : dict
-       dictionary of gibbs parameters. See below.
+       Dictionary of parameters for the Gibbs sampler. See below.
     clip : boolean, optional
-       True by default. If true, pixel value of the result above 1 or
-       under -1 are thresholded for skimage pipeline
-       compatibility.
+       True by default. If true, pixel values of the result above 1 or
+       under -1 are thresholded for skimage pipeline compatibility.
 
     Returns
     -------
@@ -187,12 +186,12 @@ def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
        samples, see Notes section). 1e-4 by default.
     burnin : int
        The number of sample to ignore to start computation of the
-       mean. 100 by default.
+       mean. 15 by default.
     min_iter : int
        The minimum number of iterations. 30 by default.
     max_iter : int
        The maximum number of iterations if ``threshold`` is not
-       satisfied. 150 by default.
+       satisfied. 200 by default.
     callback : callable (None by default)
        A user provided callable to which is passed, if the function
        exists, the current image sample for whatever purpose. The user
@@ -203,12 +202,12 @@ def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
     Examples
     --------
     >>> from skimage import color, data, restoration
-    >>> lena = color.rgb2gray(data.lena())
+    >>> img = color.rgb2gray(data.astronaut())
     >>> from scipy.signal import convolve2d
     >>> psf = np.ones((5, 5)) / 25
-    >>> lena = convolve2d(lena, psf, 'same')
-    >>> lena += 0.1 * lena.std() * np.random.standard_normal(lena.shape)
-    >>> deconvolved_lena = restoration.unsupervised_wiener(lena, psf)
+    >>> img = convolve2d(img, psf, 'same')
+    >>> img += 0.1 * img.std() * np.random.standard_normal(img.shape)
+    >>> deconvolved_img = restoration.unsupervised_wiener(img, psf)
 
     Notes
     -----
@@ -217,10 +216,10 @@ def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
     a sum over all the possible images weighted by their respective
     probability. Given the size of the problem, the exact sum is not
     tractable. This algorithm use of MCMC to draw image under the
-    posterior law. The practical idea is to only draw high probable
-    image since they have the biggest contribution to the mean. At the
-    opposite, the lowest probable image are draw less often since
-    their contribution are low. Finally the empirical mean of these
+    posterior law. The practical idea is to only draw highly probable
+    images since they have the biggest contribution to the mean. At the
+    opposite, the less probable images are drawn less often since
+    their contribution is low. Finally the empirical mean of these
     samples give us an estimation of the mean, and an exact
     computation with an infinite sample set.
 
@@ -262,8 +261,8 @@ def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
 
     # The correlation of the object in Fourier space (if size is big,
     # this can reduce computation time in the loop)
-    areg2 = np.abs(reg)**2
-    atf2 = np.abs(trans_fct)**2
+    areg2 = np.abs(reg) ** 2
+    atf2 = np.abs(trans_fct) ** 2
 
     # The Fourier transfrom may change the image.size attribut, so we
     # store it.
@@ -320,7 +319,7 @@ def unsupervised_wiener(image, psf, reg=None, user_params=None, is_real=True,
     # Empirical average \approx POSTMEAN Eq. 44
     x_postmean = x_postmean / (iteration - params['burnin'])
     if is_real:
-        x_postmean = uft.uirfft2(x_postmean)
+        x_postmean = uft.uirfft2(x_postmean, shape=image.shape)
     else:
         x_postmean = uft.uifft2(x_postmean)
 
@@ -337,21 +336,20 @@ def richardson_lucy(image, psf, iterations=50, clip=True):
     Parameters
     ----------
     image : ndarray
-       Input degraded image
+       Input degraded image (can be N dimensional).
     psf : ndarray
-       The point spread function
+       The point spread function.
     iterations : int
-       Number of iterations. This parameter play to role of
+       Number of iterations. This parameter plays the role of
        regularisation.
     clip : boolean, optional
        True by default. If true, pixel value of the result above 1 or
-       under -1 are thresholded for skimage pipeline
-       compatibility.
+       under -1 are thresholded for skimage pipeline compatibility.
 
     Returns
     -------
     im_deconv : ndarray
-       The deconvolved image
+       The deconvolved image.
 
     Examples
     --------
@@ -365,15 +363,31 @@ def richardson_lucy(image, psf, iterations=50, clip=True):
 
     References
     ----------
-    .. [2] http://en.wikipedia.org/wiki/Richardson%E2%80%93Lucy_deconvolution
+    .. [1] http://en.wikipedia.org/wiki/Richardson%E2%80%93Lucy_deconvolution
     """
+    # compute the times for direct convolution and the fft method. The fft is of
+    # complexity O(N log(N)) for each dimension and the direct method does
+    # straight arithmetic (and is O(n*k) to add n elements k times)
+    direct_time = np.prod(image.shape + psf.shape)
+    fft_time =  np.sum([n*np.log(n) for n in image.shape + psf.shape])
+
+    # see whether the fourier transform convolution method or the direct
+    # convolution method is faster (discussed in scikit-image PR #1792)
+    time_ratio = 40.032 * fft_time / direct_time
+
+    if time_ratio <= 1 or len(image.shape) > 2:
+        convolve_method = fftconvolve
+    else:
+        convolve_method = convolve
+
     image = image.astype(np.float)
     psf = psf.astype(np.float)
     im_deconv = 0.5 * np.ones(image.shape)
     psf_mirror = psf[::-1, ::-1]
+
     for _ in range(iterations):
-        relative_blur = image / convolve2d(im_deconv, psf, 'same')
-        im_deconv *= convolve2d(relative_blur, psf_mirror, 'same')
+        relative_blur = image / convolve_method(im_deconv, psf, 'same')
+        im_deconv *= convolve_method(relative_blur, psf_mirror, 'same')
 
     if clip:
         im_deconv[im_deconv > 1] = 1
