@@ -7,6 +7,10 @@ from .boundaries import find_boundaries, mark_boundaries
 from ._clear_border import clear_border
 from ._join import join_segmentations, relabel_from_one, relabel_sequential
 from ..morphology import watershed
+from ._chan_vese import chan_vese
+from .morphsnakes import (morphological_geodesic_active_contour,
+                          morphological_chan_vese, inverse_gaussian_gradient,
+                          circle_level_set, checkerboard_level_set)
 
 
 __all__ = ['random_walker',
@@ -20,4 +24,11 @@ __all__ = ['random_walker',
            'join_segmentations',
            'relabel_from_one',
            'relabel_sequential',
-           'watershed']
+           'watershed',
+           'chan_vese',
+           'morphological_geodesic_active_contour',
+           'morphological_chan_vese',
+           'inverse_gaussian_gradient',
+           'circle_level_set',
+           'checkerboard_level_set'
+           ]
