@@ -1,9 +1,8 @@
 import numpy as np
-from skimage import img_as_float
-import scipy
 import scipy.linalg
-from scipy.interpolate import RectBivariateSpline, interp2d
-from skimage.filters import sobel
+from scipy.interpolate import RectBivariateSpline
+from ..util import img_as_float
+from ..filters import sobel
 
 
 def active_contour(image, snake, alpha=0.01, beta=0.1,
@@ -88,17 +87,6 @@ def active_contour(image, snake, alpha=0.01, beta=0.1,
     25
 
     """
-    split_version = scipy.__version__.split('.')
-    if not(split_version[-1].isdigit()):
-        split_version.pop()
-    scipy_version = list(map(int, split_version))
-    new_scipy = scipy_version[0] > 0 or \
-                (scipy_version[0] == 0 and scipy_version[1] >= 14)
-    if not new_scipy:
-        raise NotImplementedError('You are using an old version of scipy. '
-                      'Active contours is implemented for scipy versions '
-                      '0.14.0 and above.')
-
     max_iterations = int(max_iterations)
     if max_iterations <= 0:
         raise ValueError("max_iterations should be >0.")
@@ -134,14 +122,9 @@ def active_contour(image, snake, alpha=0.01, beta=0.1,
         img = w_line*img + w_edge*edge[0]
 
     # Interpolate for smoothness:
-    if new_scipy:
-        intp = RectBivariateSpline(np.arange(img.shape[1]),
-                                   np.arange(img.shape[0]),
-                                   img.T, kx=2, ky=2, s=0)
-    else:
-        intp = np.vectorize(interp2d(np.arange(img.shape[1]),
-                        np.arange(img.shape[0]), img, kind='cubic',
-                        copy=False, bounds_error=False, fill_value=0))
+    intp = RectBivariateSpline(np.arange(img.shape[1]),
+                               np.arange(img.shape[0]),
+                               img.T, kx=2, ky=2, s=0)
 
     x, y = snake[:, 0].astype(np.float), snake[:, 1].astype(np.float)
     xsave = np.empty((convergence_order, len(x)))
@@ -192,12 +175,8 @@ def active_contour(image, snake, alpha=0.01, beta=0.1,
 
     # Explicit time stepping for image energy minimization:
     for i in range(max_iterations):
-        if new_scipy:
-            fx = intp(x, y, dx=1, grid=False)
-            fy = intp(x, y, dy=1, grid=False)
-        else:
-            fx = intp(x, y, dx=1)
-            fy = intp(x, y, dy=1)
+        fx = intp(x, y, dx=1, grid=False)
+        fy = intp(x, y, dy=1, grid=False)
         if sfixed:
             fx[0] = 0
             fy[0] = 0
@@ -233,7 +212,7 @@ def active_contour(image, snake, alpha=0.01, beta=0.1,
             ysave[j, :] = y
         else:
             dist = np.min(np.max(np.abs(xsave-x[None, :]) +
-                   np.abs(ysave-y[None, :]), 1))
+                                 np.abs(ysave-y[None, :]), 1))
             if dist < convergence:
                 break
 
