@@ -13,7 +13,6 @@ from scipy import sparse, ndimage as ndi
 
 from .._shared.utils import warn
 
-
 # executive summary for next code block: try to import umfpack from
 # scipy, but make sure not to raise a fuss if it fails since it's only
 # needed to speed up a few cases.
@@ -39,10 +38,18 @@ try:
     amg_loaded = True
 except ImportError:
     amg_loaded = False
-from scipy.sparse.linalg import cg
+
 from ..util import img_as_float
 from ..filters import rank_order
 
+from scipy.sparse.linalg import cg
+import scipy
+from distutils.version import LooseVersion as Version
+import functools
+
+if Version(scipy.__version__) >= Version('1.1'):
+    cg = functools.partial(cg, atol=0)
+
 #-----------Laplacian--------------------
 
 
@@ -188,6 +195,20 @@ def _build_laplacian(data, spacing, mask=None, beta=50,
     return lap
 
 
+def _check_isolated_seeds(labels):
+    """
+    Prune isolated seed pixels to prevent labeling errors, and
+    return coordinates and label values of isolated seeds, so
+    that it is possible to put labels back in random walker output.
+    """
+    fill = ndi.binary_propagation(labels == 0, mask=(labels >= 0))
+    isolated = np.logical_and(labels > 0, np.logical_not(fill))
+    inds = np.nonzero(isolated)
+    values = labels[inds]
+    labels[inds] = -1
+    return inds, values
+
+
 #----------- Random walker algorithm --------------------------------
 
 
@@ -413,6 +434,10 @@ def random_walker(data, labels, beta=130, mode='bf', tol=1.e-3, copy=True,
         labels = np.copy(labels)
     label_values = np.unique(labels)
 
+    # If some labeled pixels are isolated inside pruned zones, prune them
+    # as well and keep the labels for the final output
+    inds_isolated_seeds, isolated_values = _check_isolated_seeds(labels)
+
     # Reorder label values to have consecutive integers (no gaps)
     if np.any(np.diff(label_values) != 1):
         mask = labels >= 0
@@ -426,6 +451,8 @@ def random_walker(data, labels, beta=130, mode='bf', tol=1.e-3, copy=True,
         labels[np.logical_and(np.logical_not(filled), labels == 0)] = -1
         del filled
     labels = np.atleast_3d(labels)
+
+
     if np.any(labels < 0):
         lap_sparse = _build_laplacian(data, spacing, mask=labels >= 0,
                                       beta=beta, multichannel=multichannel)
@@ -458,6 +485,9 @@ def random_walker(data, labels, beta=130, mode='bf', tol=1.e-3, copy=True,
     # Clean up results
     if return_full_prob:
         labels = labels.astype(np.float)
+        # Put back labels of isolated seeds
+        if len(isolated_values) > 0:
+            labels[inds_isolated_seeds] = isolated_values
         X = np.array([_clean_labels_ar(Xline, labels, copy=True).reshape(dims)
                       for Xline in X])
         for i in range(1, int(labels.max()) + 1):
@@ -466,6 +496,8 @@ def random_walker(data, labels, beta=130, mode='bf', tol=1.e-3, copy=True,
             X[i - 1, mask_i] = 1
     else:
         X = _clean_labels_ar(X + 1, labels).reshape(dims)
+        # Put back labels of isolated seeds
+        X[inds_isolated_seeds] = isolated_values
     return X
 
 
@@ -477,7 +509,7 @@ def _solve_bf(lap_sparse, B, return_full_prob=False):
     """
     lap_sparse = lap_sparse.tocsc()
     solver = sparse.linalg.factorized(lap_sparse.astype(np.double))
-    X = np.array([solver(np.array((-B[i]).todense()).ravel())
+    X = np.array([solver(np.array((-B[i]).toarray()).ravel())
                   for i in range(len(B))])
     if not return_full_prob:
         X = np.argmax(X, axis=0)
@@ -493,7 +525,7 @@ def _solve_cg(lap_sparse, B, tol, return_full_prob=False):
     lap_sparse = lap_sparse.tocsc()
     X = []
     for i in range(len(B)):
-        x0 = cg(lap_sparse, -B[i].todense(), tol=tol)[0]
+        x0 = cg(lap_sparse, -B[i].toarray(), tol=tol)[0]
         X.append(x0)
     if not return_full_prob:
         X = np.array(X)
@@ -512,7 +544,7 @@ def _solve_cg_mg(lap_sparse, B, tol, return_full_prob=False):
     ml = ruge_stuben_solver(lap_sparse)
     M = ml.aspreconditioner(cycle='V')
     for i in range(len(B)):
-        x0 = cg(lap_sparse, -B[i].todense(), tol=tol, M=M, maxiter=30)[0]
+        x0 = cg(lap_sparse, -B[i].toarray(), tol=tol, M=M, maxiter=30)[0]
         X.append(x0)
     if not return_full_prob:
         X = np.array(X)
