@@ -11,8 +11,8 @@ from ._geometric import (estimate_transform,
                          ProjectiveTransform, FundamentalMatrixTransform,
                          EssentialMatrixTransform, PolynomialTransform,
                          PiecewiseAffineTransform)
-from ._warps import (swirl, resize, rotate, rescale, downscale_local_mean,
-                     warp, warp_coords)
+from ._warps import (swirl, resize, rotate, rescale,
+                     downscale_local_mean, warp, warp_coords)
 from .pyramids import (pyramid_reduce, pyramid_expand,
                        pyramid_gaussian, pyramid_laplacian)
 from .seam_carving import seam_carve
