@@ -3,23 +3,19 @@ import numpy as np
 from scipy import ndimage as ndi
 from ..transform import resize
 from ..util import img_as_float
+from ._warps import _multichannel_default
 
 
-def _smooth(image, sigma, mode, cval):
+def _smooth(image, sigma, mode, cval, multichannel=None):
     """Return image with each channel smoothed by the Gaussian filter."""
-
+    multichannel = _multichannel_default(multichannel, image.ndim)
     smoothed = np.empty(image.shape, dtype=np.double)
 
-    # apply Gaussian filter to all dimensions independently
-    if image.ndim == 3:
-        for dim in range(image.shape[2]):
-            ndi.gaussian_filter(image[..., dim], sigma,
-                                output=smoothed[..., dim],
-                                mode=mode, cval=cval)
-    else:
-        ndi.gaussian_filter(image, sigma, output=smoothed,
-                            mode=mode, cval=cval)
-
+    # apply Gaussian filter to all channels independently
+    if multichannel:
+        sigma = (sigma, )*(image.ndim - 1) + (0, )
+    ndi.gaussian_filter(image, sigma, output=smoothed,
+                        mode=mode, cval=cval)
     return smoothed
 
 
@@ -29,12 +25,12 @@ def _check_factor(factor):
 
 
 def pyramid_reduce(image, downscale=2, sigma=None, order=1,
-                   mode='reflect', cval=0):
+                   mode='reflect', cval=0, multichannel=None):
     """Smooth and then downsample image.
 
     Parameters
     ----------
-    image : array
+    image : ndarray
         Input image.
     downscale : float, optional
         Downscale factor.
@@ -50,6 +46,11 @@ def pyramid_reduce(image, downscale=2, sigma=None, order=1,
         cval is the value when mode is equal to 'constant'.
     cval : float, optional
         Value to fill past edges of input if mode is 'constant'.
+    multichannel : bool, optional
+        Whether the last axis of the image is to be interpreted as multiple
+        channels or another spatial dimension. By default, is set to True for
+        3D (2D+color) inputs, and False for others. Starting in release 0.16,
+        this will always default to False.
 
     Returns
     -------
@@ -61,34 +62,33 @@ def pyramid_reduce(image, downscale=2, sigma=None, order=1,
     .. [1] http://web.mit.edu/persci/people/adelson/pub_pdfs/pyramid83.pdf
 
     """
-
+    multichannel = _multichannel_default(multichannel, image.ndim)
     _check_factor(downscale)
 
     image = img_as_float(image)
 
-    rows = image.shape[0]
-    cols = image.shape[1]
-    out_rows = math.ceil(rows / float(downscale))
-    out_cols = math.ceil(cols / float(downscale))
+    out_shape = tuple([math.ceil(d / float(downscale)) for d in image.shape])
+    if multichannel:
+        out_shape = out_shape[:-1]
 
     if sigma is None:
         # automatically determine sigma which covers > 99% of distribution
         sigma = 2 * downscale / 6.0
 
-    smoothed = _smooth(image, sigma, mode, cval)
-    out = resize(smoothed, (out_rows, out_cols), order=order,
-                 mode=mode, cval=cval)
+    smoothed = _smooth(image, sigma, mode, cval, multichannel)
+    out = resize(smoothed, out_shape, order=order, mode=mode, cval=cval,
+                 anti_aliasing=False)
 
     return out
 
 
 def pyramid_expand(image, upscale=2, sigma=None, order=1,
-                   mode='reflect', cval=0):
+                   mode='reflect', cval=0, multichannel=None):
     """Upsample and then smooth image.
 
     Parameters
     ----------
-    image : array
+    image : ndarray
         Input image.
     upscale : float, optional
         Upscale factor.
@@ -104,6 +104,12 @@ def pyramid_expand(image, upscale=2, sigma=None, order=1,
         cval is the value when mode is equal to 'constant'.
     cval : float, optional
         Value to fill past edges of input if mode is 'constant'.
+    multichannel : bool, optional
+        Whether the last axis of the image is to be interpreted as multiple
+        channels or another spatial dimension. By default, is set to True for
+        3D (2D+color) inputs, and False for others. Starting in release 0.16,
+        this will always default to False.
+
 
     Returns
     -------
@@ -115,29 +121,28 @@ def pyramid_expand(image, upscale=2, sigma=None, order=1,
     .. [1] http://web.mit.edu/persci/people/adelson/pub_pdfs/pyramid83.pdf
 
     """
-
+    multichannel = _multichannel_default(multichannel, image.ndim)
     _check_factor(upscale)
 
     image = img_as_float(image)
 
-    rows = image.shape[0]
-    cols = image.shape[1]
-    out_rows = math.ceil(upscale * rows)
-    out_cols = math.ceil(upscale * cols)
+    out_shape = tuple([math.ceil(upscale * d) for d in image.shape])
+    if multichannel:
+        out_shape = out_shape[:-1]
 
     if sigma is None:
         # automatically determine sigma which covers > 99% of distribution
         sigma = 2 * upscale / 6.0
 
-    resized = resize(image, (out_rows, out_cols), order=order,
-                     mode=mode, cval=cval)
-    out = _smooth(resized, sigma, mode, cval)
+    resized = resize(image, out_shape, order=order,
+                     mode=mode, cval=cval, anti_aliasing=False)
+    out = _smooth(resized, sigma, mode, cval, multichannel)
 
     return out
 
 
 def pyramid_gaussian(image, max_layer=-1, downscale=2, sigma=None, order=1,
-                     mode='reflect', cval=0):
+                     mode='reflect', cval=0, multichannel=None):
     """Yield images of the Gaussian pyramid formed by the input image.
 
     Recursively applies the `pyramid_reduce` function to the image, and yields
@@ -150,7 +155,7 @@ def pyramid_gaussian(image, max_layer=-1, downscale=2, sigma=None, order=1,
 
     Parameters
     ----------
-    image : array
+    image : ndarray
         Input image.
     max_layer : int
         Number of layers for the pyramid. 0th layer is the original image.
@@ -169,6 +174,12 @@ def pyramid_gaussian(image, max_layer=-1, downscale=2, sigma=None, order=1,
         cval is the value when mode is equal to 'constant'.
     cval : float, optional
         Value to fill past edges of input if mode is 'constant'.
+    multichannel : bool, optional
+        Whether the last axis of the image is to be interpreted as multiple
+        channels or another spatial dimension. By default, is set to True for
+        3D (2D+color) inputs, and False for others. Starting in release 0.16,
+        this will always default to False.
+
 
     Returns
     -------
@@ -180,15 +191,13 @@ def pyramid_gaussian(image, max_layer=-1, downscale=2, sigma=None, order=1,
     .. [1] http://web.mit.edu/persci/people/adelson/pub_pdfs/pyramid83.pdf
 
     """
-
     _check_factor(downscale)
 
     # cast to float for consistent data type in pyramid
     image = img_as_float(image)
 
     layer = 0
-    rows = image.shape[0]
-    cols = image.shape[1]
+    current_shape = image.shape
 
     prev_layer_image = image
     yield image
@@ -199,23 +208,21 @@ def pyramid_gaussian(image, max_layer=-1, downscale=2, sigma=None, order=1,
         layer += 1
 
         layer_image = pyramid_reduce(prev_layer_image, downscale, sigma, order,
-                                     mode, cval)
+                                     mode, cval, multichannel=multichannel)
 
-        prev_rows = rows
-        prev_cols = cols
+        prev_shape = np.asarray(current_shape)
         prev_layer_image = layer_image
-        rows = layer_image.shape[0]
-        cols = layer_image.shape[1]
+        current_shape = np.asarray(layer_image.shape)
 
         # no change to previous pyramid layer
-        if prev_rows == rows and prev_cols == cols:
+        if np.all(current_shape == prev_shape):
             break
 
         yield layer_image
 
 
 def pyramid_laplacian(image, max_layer=-1, downscale=2, sigma=None, order=1,
-                      mode='reflect', cval=0):
+                      mode='reflect', cval=0, multichannel=None):
     """Yield images of the laplacian pyramid formed by the input image.
 
     Each layer contains the difference between the downsampled and the
@@ -231,7 +238,7 @@ def pyramid_laplacian(image, max_layer=-1, downscale=2, sigma=None, order=1,
 
     Parameters
     ----------
-    image : array
+    image : ndarray
         Input image.
     max_layer : int
         Number of layers for the pyramid. 0th layer is the original image.
@@ -250,6 +257,12 @@ def pyramid_laplacian(image, max_layer=-1, downscale=2, sigma=None, order=1,
         cval is the value when mode is equal to 'constant'.
     cval : float, optional
         Value to fill past edges of input if mode is 'constant'.
+    multichannel : bool, optional
+        Whether the last axis of the image is to be interpreted as multiple
+        channels or another spatial dimension. By default, is set to True for
+        3D (2D+color) inputs, and False for others. Starting in release 0.16,
+        this will always default to False.
+
 
     Returns
     -------
@@ -262,7 +275,7 @@ def pyramid_laplacian(image, max_layer=-1, downscale=2, sigma=None, order=1,
     .. [2] http://sepwww.stanford.edu/data/media/public/sep/morgan/texturematch/paper_html/node3.html
 
     """
-
+    multichannel = _multichannel_default(multichannel, image.ndim)
     _check_factor(downscale)
 
     # cast to float for consistent data type in pyramid
@@ -272,32 +285,28 @@ def pyramid_laplacian(image, max_layer=-1, downscale=2, sigma=None, order=1,
         # automatically determine sigma which covers > 99% of distribution
         sigma = 2 * downscale / 6.0
 
-    layer = 0
-    rows = image.shape[0]
-    cols = image.shape[1]
+    current_shape = image.shape
 
-    smoothed_image = _smooth(image, sigma, mode, cval)
+    smoothed_image = _smooth(image, sigma, mode, cval, multichannel)
     yield image - smoothed_image
 
     # build downsampled images until max_layer is reached or downscale process
     # does not change image size
-    while layer != max_layer:
-        layer += 1
+    if max_layer == -1:
+        max_layer = int(np.ceil(math.log(np.max(current_shape), downscale)))
 
-        out_rows = math.ceil(rows / float(downscale))
-        out_cols = math.ceil(cols / float(downscale))
+    for layer in range(max_layer):
 
-        resized_image = resize(smoothed_image, (out_rows, out_cols),
-                               order=order, mode=mode, cval=cval)
-        smoothed_image = _smooth(resized_image, sigma, mode, cval)
+        out_shape = tuple(
+            [math.ceil(d / float(downscale)) for d in current_shape])
 
-        prev_rows = rows
-        prev_cols = cols
-        rows = resized_image.shape[0]
-        cols = resized_image.shape[1]
+        if multichannel:
+            out_shape = out_shape[:-1]
 
-        # no change to previous pyramid layer
-        if prev_rows == rows and prev_cols == cols:
-            break
+        resized_image = resize(smoothed_image, out_shape, order=order,
+                               mode=mode, cval=cval, anti_aliasing=False)
+        smoothed_image = _smooth(resized_image, sigma, mode, cval,
+                                 multichannel)
+        current_shape = np.asarray(resized_image.shape)
 
         yield resized_image - smoothed_image
