@@ -1,19 +1,22 @@
 from __future__ import print_function, division
 
-import numpy as np
-from numpy.testing import assert_raises
+import os
 import itertools
-import os.path
 
-from skimage.transform import radon, iradon, iradon_sart, rescale
-from skimage.io import imread
+import numpy as np
 from skimage import data_dir
+from skimage.io import imread
+from skimage.transform import radon, iradon, iradon_sart, rescale
+
+from skimage._shared import testing
 from skimage._shared.testing import test_parallel
 from skimage._shared._warnings import expected_warnings
 
+
 PHANTOM = imread(os.path.join(data_dir, "phantom.png"),
-                   as_grey=True)[::2, ::2]
-PHANTOM = rescale(PHANTOM, 0.5, order=1, mode='reflect')
+                 as_gray=True)[::2, ::2]
+PHANTOM = rescale(PHANTOM, 0.5, order=1,
+                  mode='constant', anti_aliasing=False, multichannel=False)
 
 
 def _debug_plot(original, result, sinogram=None):
@@ -57,14 +60,23 @@ def check_radon_center(shape, circle):
     assert np.std(sinogram_max) < 1e-6
 
 
-def test_radon_center():
-    shapes = [(16, 16), (17, 17)]
-    circles = [False, True]
-    for shape, circle in itertools.product(shapes, circles):
-        yield check_radon_center, shape, circle
-    rectangular_shapes = [(32, 16), (33, 17)]
-    for shape in rectangular_shapes:
-        yield check_radon_center, shape, False
+shapes_for_test_radon_center = [(16, 16), (17, 17)]
+circles_for_test_radon_center = [False, True]
+
+
+@testing.parametrize("shape, circle",
+                     itertools.product(shapes_for_test_radon_center,
+                                       circles_for_test_radon_center))
+def test_radon_center(shape, circle):
+    check_radon_center(shape, circle)
+
+
+rectangular_shapes = [(32, 16), (33, 17)]
+
+
+@testing.parametrize("shape", rectangular_shapes)
+def test_radon_center_rectangular(shape):
+    check_radon_center(shape, False)
 
 
 def check_iradon_center(size, theta, circle):
@@ -105,19 +117,24 @@ def check_iradon_center(size, theta, circle):
     assert np.allclose(reconstruction, reconstruction_opposite)
 
 
-def test_iradon_center():
-    sizes = [16, 17]
-    thetas = [0, 90]
-    circles = [False, True]
-    for size, theta, circle in itertools.product(sizes, thetas, circles):
-        yield check_iradon_center, size, theta, circle
+sizes_for_test_iradon_center = [16, 17]
+thetas_for_test_iradon_center = [0, 90]
+circles_for_test_iradon_center = [False, True]
+
+
+@testing.parametrize("size, theta, circle",
+                     itertools.product(sizes_for_test_iradon_center,
+                                       thetas_for_test_iradon_center,
+                                       circles_for_test_radon_center))
+def test_iradon_center(size, theta, circle):
+    check_iradon_center(size, theta, circle)
 
 
 def check_radon_iradon(interpolation_type, filter_type):
     debug = False
     image = PHANTOM
     reconstructed = iradon(radon(image, circle=False), filter=filter_type,
-                           interpolation=interpolation_type)
+                           interpolation=interpolation_type, circle=False)
     delta = np.mean(np.abs(image - reconstructed))
     print('\n\tmean error:', delta)
     if debug:
@@ -132,14 +149,18 @@ def check_radon_iradon(interpolation_type, filter_type):
     assert delta < allowed_delta
 
 
-def test_radon_iradon():
-    filter_types = ["ramp", "shepp-logan", "cosine", "hamming", "hann"]
-    interpolation_types = ['linear', 'nearest']
-    for interpolation_type, filter_type in \
-            itertools.product(interpolation_types, filter_types):
-        yield check_radon_iradon, interpolation_type, filter_type
-    # cubic interpolation is slow; only run one test for it
-    yield check_radon_iradon, 'cubic', 'shepp-logan'
+filter_types = ["ramp", "shepp-logan", "cosine", "hamming", "hann"]
+interpolation_types = ['linear', 'nearest']
+radon_iradon_inputs = list(itertools.product(interpolation_types,
+                                             filter_types))
+# cubic interpolation is slow; only run one test for it
+radon_iradon_inputs.append(('cubic', 'shepp-logan'))
+
+
+@testing.parametrize("interpolation_type, filter_type",
+                     radon_iradon_inputs)
+def test_radon_iradon(interpolation_type, filter_type):
+    check_radon_iradon(interpolation_type, filter_type)
 
 
 def test_iradon_angles():
@@ -154,7 +175,8 @@ def test_iradon_angles():
     theta = np.linspace(0, 180, nb_angles, endpoint=False)
     radon_image_200 = radon(image, theta=theta, circle=False)
     reconstructed = iradon(radon_image_200, circle=False)
-    delta_200 = np.mean(abs(_rescale_intensity(image) - _rescale_intensity(reconstructed)))
+    delta_200 = np.mean(abs(_rescale_intensity(image) -
+                            _rescale_intensity(reconstructed)))
     assert delta_200 < 0.03
     # Lower number of projections
     nb_angles = 80
@@ -184,21 +206,35 @@ def check_radon_iradon_minimal(shape, slices):
                 == np.unravel_index(np.argmax(image), image.shape))
 
 
-def test_radon_iradon_minimal():
-    shapes = [(3, 3), (4, 4), (5, 5)]
-    for shape in shapes:
+shapes = [(3, 3), (4, 4), (5, 5)]
+
+
+def generate_test_data_for_radon_iradon_minimal(shapes):
+    def shape2coordinates(shape):
         c0, c1 = shape[0] // 2, shape[1] // 2
         coordinates = itertools.product((c0 - 1, c0, c0 + 1),
                                         (c1 - 1, c1, c1 + 1))
-        for coordinate in coordinates:
-            yield check_radon_iradon_minimal, shape, coordinate
+        return coordinates
+
+    def shape2shapeandcoordinates(shape):
+        return itertools.product([shape], shape2coordinates(shape))
+
+    return itertools.chain.from_iterable([shape2shapeandcoordinates(shape)
+                                          for shape in shapes])
+
+
+@testing.parametrize("shape, coordinate",
+                     generate_test_data_for_radon_iradon_minimal(shapes))
+def test_radon_iradon_minimal(shape, coordinate):
+    check_radon_iradon_minimal(shape, coordinate)
 
 
 def test_reconstruct_with_wrong_angles():
     a = np.zeros((3, 3))
     p = radon(a, theta=[0, 1, 2], circle=False)
     iradon(p, theta=[0, 1, 2], circle=False)
-    assert_raises(ValueError, iradon, p, theta=[0, 1, 2, 3])
+    with testing.raises(ValueError):
+        iradon(p, theta=[0, 1, 2, 3])
 
 
 def _random_circle(shape):
@@ -243,7 +279,10 @@ def check_sinogram_circle_to_square(size):
     image = _random_circle((size, size))
     theta = np.linspace(0., 180., size, False)
     sinogram_circle = radon(image, theta, circle=True)
-    argmax_shape = lambda a: np.unravel_index(np.argmax(a), a.shape)
+
+    def argmax_shape(a):
+        return np.unravel_index(np.argmax(a), a.shape)
+
     print('\n\targmax of circle:', argmax_shape(sinogram_circle))
     sinogram_square = radon(image, theta, circle=False)
     print('\targmax of square:', argmax_shape(sinogram_square))
@@ -252,13 +291,13 @@ def check_sinogram_circle_to_square(size):
           argmax_shape(sinogram_circle_to_square))
     error = abs(sinogram_square - sinogram_circle_to_square)
     print(np.mean(error), np.max(error))
-    assert (argmax_shape(sinogram_square)
-            == argmax_shape(sinogram_circle_to_square))
+    assert (argmax_shape(sinogram_square) ==
+            argmax_shape(sinogram_circle_to_square))
 
 
-def test_sinogram_circle_to_square():
-    for size in (50, 51):
-        yield check_sinogram_circle_to_square, size
+@testing.parametrize("size", (50, 51))
+def test_sinogram_circle_to_square(size):
+    check_sinogram_circle_to_square(size)
 
 
 def check_radon_iradon_circle(interpolation, shape, output_size):
@@ -289,13 +328,20 @@ def check_radon_iradon_circle(interpolation, shape, output_size):
     np.allclose(reconstruction_rectangle, reconstruction_circle)
 
 
-def test_radon_iradon_circle():
-    shape = (61, 79)
-    interpolations = ('nearest', 'linear')
-    output_sizes = (None, min(shape), max(shape), 97)
-    for interpolation, output_size in itertools.product(interpolations,
-                                                        output_sizes):
-        yield check_radon_iradon_circle, interpolation, shape, output_size
+# if adding more shapes to test data, you might want to look at commit d0f2bac3f
+shapes_radon_iradon_circle = ((61, 79), )
+interpolations = ('nearest', 'linear')
+output_sizes = (None,
+                min(shapes_radon_iradon_circle[0]),
+                max(shapes_radon_iradon_circle[0]),
+                97)
+
+
+@testing.parametrize("shape, interpolation, output_size",
+                     itertools.product(shapes_radon_iradon_circle,
+                                       interpolations, output_sizes))
+def test_radon_iradon_circle(shape, interpolation, output_size):
+    check_radon_iradon_circle(interpolation, shape, output_size)
 
 
 def test_order_angles_golden_ratio():
@@ -315,7 +361,8 @@ def test_order_angles_golden_ratio():
 def test_iradon_sart():
     debug = False
 
-    image = rescale(PHANTOM, 0.8, mode='reflect')
+    image = rescale(PHANTOM, 0.8, mode='reflect',
+                    multichannel=False, anti_aliasing=False)
     theta_ordered = np.linspace(0., 180., image.shape[0], endpoint=False)
     theta_missing_wedge = np.linspace(0., 150., image.shape[0], endpoint=True)
     for theta, error_factor in ((theta_ordered, 1.),
@@ -372,8 +419,3 @@ def test_iradon_sart():
         delta = np.mean(np.abs(reconstructed - image))
         print('delta (1 iteration, shifted sinogram) =', delta)
         assert delta < 0.022 * error_factor
-
-
-if __name__ == "__main__":
-    from numpy.testing import run_module_suite
-    run_module_suite()
