@@ -1,4 +1,5 @@
-from .dtype import (img_as_float, img_as_int, img_as_uint, img_as_ubyte,
+from .dtype import (img_as_float32, img_as_float64, img_as_float,
+                    img_as_int, img_as_uint, img_as_ubyte,
                     img_as_bool, dtype_limits)
 from .shape import view_as_blocks, view_as_windows
 from .noise import random_noise
@@ -8,6 +9,7 @@ from .arraycrop import crop
 from ._regular_grid import regular_grid, regular_seeds
 from .unique import unique_rows
 from ._invert import invert
+from ._montage import montage, montage2d
 
 from .._shared.utils import copy_func
 
@@ -15,7 +17,9 @@ from numpy import pad as numpy_pad
 pad = copy_func(numpy_pad, name='pad')
 
 
-__all__ = ['img_as_float',
+__all__ = ['img_as_float32',
+           'img_as_float64',
+           'img_as_float',
            'img_as_int',
            'img_as_uint',
            'img_as_ubyte',
@@ -25,6 +29,8 @@ __all__ = ['img_as_float',
            'view_as_windows',
            'pad',
            'crop',
+           'montage',
+           'montage2d',
            'random_noise',
            'regular_grid',
            'regular_seeds',
