@@ -1,9 +1,11 @@
-__all__ = ['view_as_blocks', 'view_as_windows']
-
+from __future__ import division
+import numbers
 import numpy as np
 from numpy.lib.stride_tricks import as_strided
 from warnings import warn
 
+__all__ = ['view_as_blocks', 'view_as_windows']
+
 
 def view_as_blocks(arr_in, block_shape):
     """Block view of the input n-dimensional array (using re-striding).
@@ -112,13 +114,14 @@ def view_as_windows(arr_in, window_shape, step=1):
     ----------
     arr_in : ndarray
         N-d input array.
-    window_shape : tuple
+    window_shape : integer or tuple of length arr_in.ndim
         Defines the shape of the elementary n-dimensional orthotope
         (better know as hyperrectangle [1]_) of the rolling window view.
-    step : int, optional
-        Number of elements to skip when moving the window forward (by
-        default, move forward by one). The value must be equal or larger
-        than one.
+        If an integer is given, the shape will be a hypercube of
+        sidelength given by its value.
+    step : integer or tuple of length arr_in.ndim
+        Indicates step size at which extraction shall be performed.
+        If integer is given, then the step is uniform in all dimensions.
 
     Returns
     -------
@@ -215,13 +218,20 @@ def view_as_windows(arr_in, window_shape, step=1):
     # -- basic checks on arguments
     if not isinstance(arr_in, np.ndarray):
         raise TypeError("`arr_in` must be a numpy ndarray")
-    if not isinstance(window_shape, tuple):
-        raise TypeError("`window_shape` must be a tuple")
-    if not (len(window_shape) == arr_in.ndim):
+
+    ndim = arr_in.ndim
+
+    if isinstance(window_shape, numbers.Number):
+        window_shape = (window_shape,) * ndim
+    if not (len(window_shape) == ndim):
         raise ValueError("`window_shape` is incompatible with `arr_in.shape`")
 
-    if step < 1:
-        raise ValueError("`step` must be >= 1")
+    if isinstance(step, numbers.Number):
+        if step < 1:
+            raise ValueError("`step` must be >= 1")
+        step = (step,) * ndim
+    if len(step) != ndim:
+        raise ValueError("`step` is incompatible with `arr_in.shape`")
 
     arr_shape = np.array(arr_in.shape)
     window_shape = np.array(window_shape, dtype=arr_shape.dtype)
@@ -239,12 +249,16 @@ def view_as_windows(arr_in, window_shape, step=1):
 
     arr_in = np.ascontiguousarray(arr_in)
 
-    new_shape = tuple((arr_shape - window_shape) // step + 1) + \
-                tuple(window_shape)
+    slices = tuple(slice(None, None, st) for st in step)
+    window_strides = np.array(arr_in.strides)
 
-    arr_strides = np.array(arr_in.strides)
-    new_strides = np.concatenate((arr_strides * step, arr_strides))
+    indexing_strides = arr_in[slices].strides
 
-    arr_out = as_strided(arr_in, shape=new_shape, strides=new_strides)
+    win_indices_shape = (((np.array(arr_in.shape) - np.array(window_shape))
+                          // np.array(step)) + 1)
 
+    new_shape = tuple(list(win_indices_shape) + list(window_shape))
+    strides = tuple(list(indexing_strides) + list(window_strides))
+
+    arr_out = as_strided(arr_in, shape=new_shape, strides=strides)
     return arr_out
