@@ -1,9 +1,8 @@
-"""Tests for array cropping."""
 from __future__ import division, absolute_import, print_function
 
 import numpy as np
-from numpy.testing import (assert_array_equal, assert_equal)
 from skimage.util import crop
+from skimage._shared.testing import (assert_array_equal, assert_equal)
 
 
 def test_multi_crop():
@@ -48,7 +47,3 @@ def test_zero_crop():
     arr = np.arange(45).reshape(9, 5)
     out = crop(arr, 0)
     assert out.shape == (9, 5)
-
-
-if __name__ == "__main__":
-    np.testing.run_module_suite()
